// Import necessary packages from d3
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Create svg and set its properties
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
  	format('.5~g')(number);

// Create the segments of the pie chart.By giving categories
// and their areas is proportionnal to the value of each categor ie. runs are my dataset category
const render = data => {
  const pieData = pie().sort(null).value(d=>d.runs)(data);
  
//   Choosing the color palette
  const colors = scaleOrdinal(d3.schemeCategory10)
  	.domain(data);
  	
  // creating arc for the circle 
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(185)
  	.padAngle(0)
  	.padRadius(0);
 // getting the data  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,200)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.runs));  
  
// The code below create the legend for the chart
  const legends = svg.append("g")
  	.attr("transform", "translate(500,10)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*35})`;
    });
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.runs));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.playersname);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat(d.data.runs));
}

// Load the dataset from .json file
json( 'Data.json' ).then(data => {
  data.forEach(d=>{
    d.runs = +d.runs;
  });
  render(data);
}) 